==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentEquipmentPlanSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁设备租赁计划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_equipment_plan_sub")
public class RentEquipmentPlanSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类型id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备类型名称
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="plan_rent_num")
    private Integer planRentNum; // 计划租赁数量
    @TableField(value="temporary_amount")
    private BigDecimal temporaryAmount; // 暂估金额	
    @TableField(value="plan_approach_date")
    private Date planApproachDate; // 计划进场日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="plan_use_day_num")
    private Integer planUseDayNum; // 计划使用天数
    @TableField(value="produce_factory")
    private String produceFactory; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName;//设备名称
    @TableField(value="equipment_code")
    private String equipmentCode;//设备编码
    @TableField(value="source_id")
    private Long sourceId;//来源id
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getPlanRentNum() {
        return planRentNum;
    }

    public void setPlanRentNum(Integer planRentNum) {
        this.planRentNum = planRentNum;
    }
    public BigDecimal getTemporaryAmount() {
        return temporaryAmount;
    }

    public void setTemporaryAmount(BigDecimal temporaryAmount) {
        this.temporaryAmount = temporaryAmount;
    }
    public Date getPlanApproachDate() {
        return planApproachDate;
    }

    public void setPlanApproachDate(Date planApproachDate) {
        this.planApproachDate = planApproachDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public Integer getPlanUseDayNum() {
        return planUseDayNum;
    }

    public void setPlanUseDayNum(Integer planUseDayNum) {
        this.planUseDayNum = planUseDayNum;
    }
    public String getProduceFactory() {
        return produceFactory;
    }

    public void setProduceFactory(String produceFactory) {
        this.produceFactory = produceFactory;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentEquipmentPlanSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁设备租赁计划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_rent_equipment_plan_sub")
public class RentEquipmentPlanSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类型id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备类型名称
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="plan_rent_num")
    private Integer planRentNum; // 计划租赁数量
    @TableField(value="temporary_amount")
    private BigDecimal temporaryAmount; // 暂估金额	
    @TableField(value="plan_approach_date")
    private Date planApproachDate; // 计划进场日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="plan_use_day_num")
    private Integer planUseDayNum; // 计划使用天数
    @TableField(value="produce_factory")
    private String produceFactory; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName;//设备名称
    @TableField(value="equipment_code")
    private String equipmentCode;//设备编码
    @TableField(value="source_id")
    private Long sourceId;//来源id
    @TableField(value="estimate_use_date")
    private Date estimateUseDate; // 预计使用日期

    public Date getEstimateUseDate() {
        return estimateUseDate;
    }

    public void setEstimateUseDate(Date estimateUseDate) {
        this.estimateUseDate = estimateUseDate;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentTypeName() {
        return equipmentTypeName;
    }

    public void setEquipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public Integer getPlanRentNum() {
        return planRentNum;
    }

    public void setPlanRentNum(Integer planRentNum) {
        this.planRentNum = planRentNum;
    }
    public BigDecimal getTemporaryAmount() {
        return temporaryAmount;
    }

    public void setTemporaryAmount(BigDecimal temporaryAmount) {
        this.temporaryAmount = temporaryAmount;
    }
    public Date getPlanApproachDate() {
        return planApproachDate;
    }

    public void setPlanApproachDate(Date planApproachDate) {
        this.planApproachDate = planApproachDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public Integer getPlanUseDayNum() {
        return planUseDayNum;
    }

    public void setPlanUseDayNum(Integer planUseDayNum) {
        this.planUseDayNum = planUseDayNum;
    }
    public String getProduceFactory() {
        return produceFactory;
    }

    public void setProduceFactory(String produceFactory) {
        this.produceFactory = produceFactory;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}
